@@ -180,6 +180,7 @@ class LibraryExperiment(object):
         self.raw_count_mat = count_mat
         if barcode_only:
             self.count_mat = count_mat
+            self.filtered_count_mat = count_mat
 
         else:
             filtered_count_mat = filter_barcodes(count_mat, self)
@@ -187,7 +188,7 @@ class LibraryExperiment(object):
             
             self.count_mat = filtered_count_mat
             
-        # normalized count matrix to counts per million
+        # normalize count matrix to counts per million
         normalized_count_mat = self.count_mat.copy()
         counts = normalized_count_mat[self.pools].values.astype(float)
         counts = (counts/np.sum(counts, axis=0))*1e6
@@ -249,13 +250,7 @@ class LibraryExperiment(object):
         
         """
         # normalize to library size and filter low reads
-        filtered_count_mat = self.count_mat
-        counts = filtered_count_mat[self.pools].values.astype(float)
-        counts = (counts/np.sum(counts, axis=0))*1e6
-        counts = global_filter_counts(counts, thr=self.global_filter_thr)
-        counts = local_filter_counts(counts, thr=self.filter_thr)
-        filtered_count_mat[self.pools] = counts
-        self.count_mat = filtered_count_mat
+
         
     
         unambiguous_data, ambiguous_data= get_ambiguity(self)
